Index: code/branches/gui/src/core/Core.cc
===================================================================
--- code/branches/gui/src/core/Core.cc	(revision 2799)
+++ code/branches/gui/src/core/Core.cc	(revision 2800)
@@ -563,7 +563,7 @@
     }
 
-    void Core::tick(const Clock& time)
-    {
-        this->tclThreadManager_->tick(time.getDeltaTime());
+    void Core::update(const Clock& time)
+    {
+        this->tclThreadManager_->update(time);
     }
 }
Index: code/branches/gui/src/core/Core.h
===================================================================
--- code/branches/gui/src/core/Core.h	(revision 2799)
+++ code/branches/gui/src/core/Core.h	(revision 2800)
@@ -66,5 +66,5 @@
 
             bool isLoaded() { return this->loaded_; }
-            void tick(const Clock& time);
+            void update(const Clock& time);
 
             static Core& getInstance() { assert(Core::singletonRef_s); return *Core::singletonRef_s; }
Index: code/branches/gui/src/core/TclThreadManager.cc
===================================================================
--- code/branches/gui/src/core/TclThreadManager.cc	(revision 2799)
+++ code/branches/gui/src/core/TclThreadManager.cc	(revision 2800)
@@ -35,4 +35,5 @@
 #include <OgreTimer.h>
 
+#include "Clock.h"
 #include "CoreIncludes.h"
 #include "ConsoleCommand.h"
@@ -598,5 +599,5 @@
     }
 
-    void TclThreadManager::tick(float dt)
+    void TclThreadManager::update(const Clock& time)
     {
         {
@@ -633,5 +634,5 @@
             boost::try_mutex::scoped_lock interpreter_lock(this->orxonoxInterpreterBundle_.interpreterMutex_);
 #endif
-            unsigned long maxtime = (unsigned long)(dt * 1000000 * TCLTHREADMANAGER_MAX_CPU_USAGE);
+            unsigned long maxtime = (unsigned long)(time.getDeltaTime() * 1000000 * TCLTHREADMANAGER_MAX_CPU_USAGE);
             Ogre::Timer timer;
             while (!this->queueIsEmpty())
Index: code/branches/gui/src/core/TclThreadManager.h
===================================================================
--- code/branches/gui/src/core/TclThreadManager.h	(revision 2799)
+++ code/branches/gui/src/core/TclThreadManager.h	(revision 2800)
@@ -90,5 +90,5 @@
             void debug(const std::string& error);
 
-            virtual void tick(float dt);
+            void update(const Clock& time);
 
             std::list<unsigned int> getThreadList() const;
Index: code/branches/gui/src/core/input/CalibratorCallback.h
===================================================================
--- code/branches/gui/src/core/input/CalibratorCallback.h	(revision 2799)
+++ code/branches/gui/src/core/input/CalibratorCallback.h	(revision 2800)
@@ -52,5 +52,5 @@
         void keyHeld    (const KeyEvent& evt) { }
 
-        void tickInput(float dt) { }
+        void updateInput(float dt) { }
     };
 }
Index: code/branches/gui/src/core/input/ExtendedInputState.cc
===================================================================
--- code/branches/gui/src/core/input/ExtendedInputState.cc	(revision 2799)
+++ code/branches/gui/src/core/input/ExtendedInputState.cc	(revision 2800)
@@ -402,13 +402,13 @@
     }
 
-    void ExtendedInputState::tickInput(float dt)
+    void ExtendedInputState::updateInput(float dt)
     {
         for (unsigned int i = 0; i < allHandlers_.size(); ++i)
         {
-            allHandlers_[i]->tickInput(dt);
-        }
-    }
-
-    void ExtendedInputState::tickInput(float dt, unsigned int device)
+            allHandlers_[i]->updateInput(dt);
+        }
+    }
+
+    void ExtendedInputState::updateInput(float dt, unsigned int device)
     {
         switch (device)
@@ -416,15 +416,15 @@
         case Keyboard:
             for (unsigned int i = 0; i < keyHandlers_.size(); ++i)
-                keyHandlers_[i]->tickKey(dt);
+                keyHandlers_[i]->updateKey(dt);
             break;
 
         case Mouse:
             for (unsigned int i = 0; i < mouseHandlers_.size(); ++i)
-                mouseHandlers_[i]->tickMouse(dt);
+                mouseHandlers_[i]->updateMouse(dt);
             break;
 
         default: // joy sticks
             for (unsigned int i = 0; i < joyStickHandlers_[device - 2].size(); ++i)
-                joyStickHandlers_[device - 2][i]->tickJoyStick(dt, device - 2);
+                joyStickHandlers_[device - 2][i]->updateJoyStick(dt, device - 2);
             break;
         }
Index: code/branches/gui/src/core/input/ExtendedInputState.h
===================================================================
--- code/branches/gui/src/core/input/ExtendedInputState.h	(revision 2799)
+++ code/branches/gui/src/core/input/ExtendedInputState.h	(revision 2800)
@@ -68,6 +68,6 @@
         ~ExtendedInputState() { }
 
-        void tickInput(float dt);
-        void tickInput(float dt, unsigned int device);
+        void updateInput(float dt);
+        void updateInput(float dt, unsigned int device);
 
         void keyPressed (const KeyEvent& evt);
Index: code/branches/gui/src/core/input/InputBuffer.cc
===================================================================
--- code/branches/gui/src/core/input/InputBuffer.cc	(revision 2799)
+++ code/branches/gui/src/core/input/InputBuffer.cc	(revision 2800)
@@ -224,8 +224,8 @@
 
     /**
-        @brief This tick() function is called by the InputManager if the InputBuffer is active.
+        @brief This update() function is called by the InputManager if the InputBuffer is active.
         @param dt Delta time
     */
-    void InputBuffer::tickInput(float dt)
+    void InputBuffer::updateInput(float dt)
     {
         timeSinceKeyPressed_ += dt;
Index: code/branches/gui/src/core/input/InputBuffer.h
===================================================================
--- code/branches/gui/src/core/input/InputBuffer.h	(revision 2799)
+++ code/branches/gui/src/core/input/InputBuffer.h	(revision 2800)
@@ -171,6 +171,6 @@
             void processKey (const KeyEvent &e);
 
-            void tickInput(float dt);
-            void tickKey(float dt) { }
+            void updateInput(float dt);
+            void updateKey(float dt) { }
 
             std::string buffer_;
Index: code/branches/gui/src/core/input/InputInterfaces.h
===================================================================
--- code/branches/gui/src/core/input/InputInterfaces.h	(revision 2799)
+++ code/branches/gui/src/core/input/InputInterfaces.h	(revision 2800)
@@ -474,5 +474,5 @@
     public:
         virtual ~InputHandler() { }
-        virtual void tickInput(float dt) = 0;
+        virtual void updateInput(float dt) = 0;
     };
 
@@ -488,5 +488,5 @@
         virtual void keyReleased(const KeyEvent& evt) = 0;
         virtual void keyHeld    (const KeyEvent& evt) = 0;
-        virtual void tickKey    (float dt) = 0;
+        virtual void updateKey    (float dt) = 0;
     };
 
@@ -504,5 +504,5 @@
         virtual void mouseMoved         (IntVector2 abs, IntVector2 rel, IntVector2 clippingSize) = 0;
         virtual void mouseScrolled      (int abs, int rel)     = 0;
-        virtual void tickMouse          (float dt) = 0;
+        virtual void updateMouse          (float dt) = 0;
     };
 
@@ -520,5 +520,5 @@
         virtual void joyStickButtonHeld    (unsigned int joyStickID, JoyStickButtonCode::ByEnum id) = 0;
         virtual void joyStickAxisMoved     (unsigned int joyStickID, unsigned int axis, float value) = 0;
-        virtual void tickJoyStick          (float dt, unsigned int joyStick) = 0;
+        virtual void updateJoyStick          (float dt, unsigned int joyStick) = 0;
     };
 
@@ -531,8 +531,8 @@
         virtual ~EmptyHandler() { }
 
-        void tickInput(float dt) { }
-        void tickJoyStick(float dt, unsigned int joyStick) { }
-        void tickMouse(float dt) { }
-        void tickKey(float dt) { }
+        void updateInput(float dt) { }
+        void updateJoyStick(float dt, unsigned int joyStick) { }
+        void updateMouse(float dt) { }
+        void updateKey(float dt) { }
 
         void keyPressed (const KeyEvent& evt) { }
Index: code/branches/gui/src/core/input/InputManager.h
===================================================================
--- code/branches/gui/src/core/input/InputManager.h	(revision 2799)
+++ code/branches/gui/src/core/input/InputManager.h	(revision 2800)
@@ -125,5 +125,5 @@
         bool requestLeaveState     (const std::string& name);
 
-        void tick(float dt);
+        void update(const Clock& time);
 
         static InputManager& getInstance()    { assert(singletonRef_s); return *singletonRef_s; }
Index: code/branches/gui/src/core/input/InputState.h
===================================================================
--- code/branches/gui/src/core/input/InputState.h	(revision 2799)
+++ code/branches/gui/src/core/input/InputState.h	(revision 2800)
@@ -71,6 +71,6 @@
         virtual void unRegisterOnLeave()                      { executorOnLeave_ = 0; }
 
-        virtual void tickInput(float dt, unsigned int device) = 0;
-        virtual void tickInput(float dt) = 0;
+        virtual void updateInput(float dt, unsigned int device) = 0;
+        virtual void updateInput(float dt) = 0;
 
         virtual void keyPressed (const KeyEvent& evt) = 0;
Index: code/branches/gui/src/core/input/KeyBinder.h
===================================================================
--- code/branches/gui/src/core/input/KeyBinder.h	(revision 2799)
+++ code/branches/gui/src/core/input/KeyBinder.h	(revision 2800)
@@ -68,8 +68,8 @@
 
     protected: // functions
-        void tickInput(float dt);
-        void tickKey(float dt) { }
-        void tickMouse(float dt);
-        void tickJoyStick(float dt, unsigned int joyStick);
+        void updateInput(float dt);
+        void updateKey(float dt) { }
+        void updateMouse(float dt);
+        void updateJoyStick(float dt, unsigned int joyStick);
         // internal
         void tickHalfAxis(HalfAxis& halfAxis);
@@ -134,5 +134,5 @@
         @brief
             Commands that have additional parameters (axes) are executed at the end of
-            the tick() so that all values can be buffered for single execution.
+            update() so that all values can be buffered for single execution.
         */
         std::vector<BufferedParamCommand*> paramCommandBuffer_;
@@ -200,5 +200,5 @@
     { joyStickButtons_[joyStickID][id].execute(KeybindMode::OnHold); }
 
-    inline void KeyBinder::tickInput(float dt)
+    inline void KeyBinder::updateInput(float dt)
     {
         // execute all buffered bindings (additional parameter)
Index: code/branches/gui/src/core/input/SimpleInputState.h
===================================================================
--- code/branches/gui/src/core/input/SimpleInputState.h	(revision 2799)
+++ code/branches/gui/src/core/input/SimpleInputState.h	(revision 2800)
@@ -59,6 +59,6 @@
         ~SimpleInputState() { }
 
-        void tickInput(float dt);
-        void tickInput(float dt, unsigned int device);
+        void updateInput(float dt);
+        void updateInput(float dt, unsigned int device);
 
         void keyPressed (const KeyEvent& evt);
@@ -87,13 +87,13 @@
     };
 
-    inline void SimpleInputState::tickInput(float dt)
+    inline void SimpleInputState::updateInput(float dt)
     {
         for (unsigned int i = 0; i < allHandlers_.size(); ++i)
         {
-            allHandlers_[i]->tickInput(dt);
+            allHandlers_[i]->updateInput(dt);
         }
     }
 
-    inline void SimpleInputState::tickInput(float dt, unsigned int device)
+    inline void SimpleInputState::updateInput(float dt, unsigned int device)
     {
         switch (device)
@@ -101,15 +101,15 @@
         case InputDevice::Keyboard:
             if (keyHandler_)
-                keyHandler_->tickKey(dt);
+                keyHandler_->updateKey(dt);
             break;
 
         case InputDevice::Mouse:
             if (mouseHandler_)
-                mouseHandler_->tickMouse(dt);
+                mouseHandler_->updateMouse(dt);
             break;
 
         default: // joy sticks
             if (joyStickHandler_[device - 2])
-                joyStickHandler_[device - 2]->tickJoyStick(dt, device - 2);
+                joyStickHandler_[device - 2]->updateJoyStick(dt, device - 2);
             break;
         }

Index: code/branches/gui/src/core/input/InputManager.cc
===================================================================
--- code/branches/gui/src/core/input/InputManager.cc	(revision 2799)
+++ code/branches/gui/src/core/input/InputManager.cc	(revision 2800)
@@ -43,4 +43,5 @@
 
 #include "util/Exception.h"
+#include "core/Clock.h"
 #include "core/CoreIncludes.h"
 #include "core/ConfigValueIncludes.h"
@@ -670,5 +671,5 @@
     @brief
         Public interface. Only reloads immediately if the call stack doesn't
-        include the tick() method.
+        include the update() method.
     @param joyStickSupport
         Whether or not to initialise joy sticks as well.
@@ -742,8 +743,8 @@
     @brief
         Updates the states and the InputState situation.
-    @param dt
-        Delta time
-    */
-    void InputManager::tick(float dt)
+    @param time
+        Clock holding the current time.
+    */
+    void InputManager::update(const Clock& time)
     {
         if (internalState_ == Uninitialised)
@@ -849,16 +850,16 @@
                 }
 
             // tick the handlers for each active handler
             for (unsigned int i = 0; i < devicesNum_; ++i)
             {
-                activeStatesTop_[i]->tickInput(dt, i);
+                activeStatesTop_[i]->updateInput(time.getDeltaTime(), i);
                 if (stateMaster_->isInputDeviceEnabled(i))
-                    stateMaster_->tickInput(dt, i);
-            }
-
-            // tick the handler with a general tick afterwards
+                    stateMaster_->updateInput(time.getDeltaTime(), i);
+            }
+
+            // update the handler with a general tick afterwards
             for (unsigned int i = 0; i < activeStatesTicked_.size(); ++i)
-                activeStatesTicked_[i]->tickInput(dt);
-            stateMaster_->tickInput(dt);
+                activeStatesTicked_[i]->updateInput(time.getDeltaTime());
+            stateMaster_->updateInput(time.getDeltaTime());
         }
 
@@ -869,5 +870,5 @@
     @brief
         Updates the currently active states (according to activeStates_) for each device.
-        Also, a list of all active states (no duplicates!) is compiled for the general tick.
+        Also, a list of all active states (no duplicates!) is compiled for the general update().
     */
     void InputManager::_updateActiveStates()
@@ -1290,5 +1291,5 @@
     @remarks
         You can't remove the internal states "empty", "calibrator" and "detector".
-        The removal process is being postponed if InputManager::tick() is currently running.
+        The removal process is being postponed if InputManager::update() is currently running.
     */
     bool InputManager::requestDestroyState(const std::string& name)
@@ -849,16 +850,16 @@
                 }
 
-            // tick the handlers for each active handler
+            // update the handlers for each active handler
             for (unsigned int i = 0; i < devicesNum_; ++i)
             {
Index: code/branches/gui/src/core/input/KeyBinder.cc
===================================================================
--- code/branches/gui/src/core/input/KeyBinder.cc	(revision 2799)
+++ code/branches/gui/src/core/input/KeyBinder.cc	(revision 2800)
@@ -309,5 +309,5 @@
     }
 
-    void KeyBinder::tickMouse(float dt)
+    void KeyBinder::updateMouse(float dt)
     {
         if (bDeriveMouseInput_)
@@ -349,5 +349,5 @@
             // Why dividing relative value by dt? The reason lies in the simple fact, that when you
             // press a button that has relative movement, that value has to be multiplied by dt to be
             // frame rate independent. This can easily (and only) be done in tickInput(float).
             // Hence we need to divide by dt here for the mouse to compensate, because the relative
             // move movements have nothing to do with dt.
@@ -362,5 +362,5 @@
     }
 
-    void KeyBinder::tickJoyStick(float dt, unsigned int joyStick)
+    void KeyBinder::updateJoyStick(float dt, unsigned int joyStick)
     {
         for (unsigned int i = 0; i < JoyStickAxisCode::numberOfAxes * 2; i++)
@@ -349,5 +349,5 @@
             // Why dividing relative value by dt? The reason lies in the simple fact, that when you
             // press a button that has relative movement, that value has to be multiplied by dt to be
-            // frame rate independent. This can easily (and only) be done in tickInput(float).
+            // frame rate independent. This can easily (and only) be done in updateInput(float).
             // Hence we need to divide by dt here for the mouse to compensate, because the relative
             // move movements have nothing to do with dt.